@@ -3,7 +3,6 @@ import json
 from fastapi import APIRouter, Depends, Query, Request, status
 from fastapi.responses import RedirectResponse
 from fief_client import FiefAsync
-from furl import furl
 
 from fief.crypto.token import generate_token
 from fief.dependencies.admin_session import get_admin_session_token, get_userinfo
@@ -21,18 +20,7 @@ async def login(request: Request, fief: FiefAsync = Depends(get_fief)):
     url = await fief.auth_url(
         redirect_uri=request.url_for("admin.auth:callback"), scope=["openid"]
     )
-
-    # Tweak the URL manually to avoid issues when running on different ports.
-    # Typically, the Fief client will be queried internally on http://localhost
-    # Thus, it'll return URL with this base.
-    # However, when running locally (e.g. Docker), it's common
-    # to expose the server on a different port, like http://localhost:8000.
-    # By replacing the port by the one of the request, we make sure
-    # to have a working redirection.
-    parsed_url = furl(url)
-    parsed_url.port = request.base_url.port
-
-    return RedirectResponse(url=parsed_url.url, status_code=status.HTTP_302_FOUND)
+    return RedirectResponse(url=url, status_code=status.HTTP_302_FOUND)
 
 
 @router.get("/callback", name="admin.auth:callback")
