@@ -1,13 +1,13 @@
 import json
 import uuid
 from datetime import datetime, timezone
-from typing import List
+from typing import List, Union
 
 from jwcrypto import jwk, jwt
 from jwcrypto.common import JWException
 from pydantic import UUID4
 
-from fief.models import Client
+from fief.models import Client, User
 from fief.schemas.user import UserDB
 
 
@@ -19,7 +19,7 @@ def generate_access_token(
     key: jwk.JWK,
     host: str,
     client: Client,
-    user: UserDB,
+    user: Union[UserDB, User],
     scope: List[str],
     lifetime_seconds: int,
 ) -> str:
