@@ -1,3 +1,4 @@
+import re
 from typing import List, Optional
 
 from pydantic import UUID4
@@ -14,6 +15,10 @@ from fief.schemas.workspace import WorkspaceCreate
 from fief.services.main_workspace import get_main_fief_client, get_main_fief_workspace
 from fief.services.workspace_db import WorkspaceDatabase
 
+LOCALHOST_DOMAIN_PATTERN = re.compile(
+    r"([^\.]+\.)?localhost(\d+)?", flags=re.IGNORECASE
+)
+
 
 class WorkspaceCreation:
     def __init__(
@@ -59,9 +64,6 @@ class WorkspaceCreation:
             workspace_user = WorkspaceUser(workspace_id=workspace.id, user_id=user_id)
             await self.workspace_user_manager.create(workspace_user)
 
-        # Allow a redirect URI on this workspace on the main Fief client
-        await self._add_fief_redirect_uri(workspace)
-
         # Create a default tenant and client
         async with get_workspace_session(workspace) as session:
             tenant_name = workspace.name
@@ -90,6 +92,9 @@ class WorkspaceCreation:
 
             await session.commit()
 
+        # Allow a redirect URI on this workspace on the main Fief client
+        await self._add_fief_redirect_uri(workspace)
+
         return workspace
 
     async def _add_fief_redirect_uri(self, workspace: Workspace):
@@ -99,7 +104,7 @@ class WorkspaceCreation:
             client_manager = ClientManager(session)
             fief_client = await get_main_fief_client()
 
-            localhost_domain = workspace.domain.endswith("localhost")
+            localhost_domain = LOCALHOST_DOMAIN_PATTERN.match(workspace.domain)
             redirect_uri = f"{'http' if localhost_domain else 'https'}://{workspace.domain}/admin/api/auth/callback"
             fief_client.redirect_uris = fief_client.redirect_uris + [redirect_uri]
 
