@@ -71,8 +71,8 @@ class Settings(BaseSettings):
     access_id_token_lifetime_seconds: int = 3600
     refresh_token_lifetime_seconds: int = 3600 * 24 * 30
 
-    fief_domain: str = "localhost"
-    fief_base_url: str = "http://localhost"
+    fief_domain: str = "localhost:8000"
+    fief_base_url: str = "http://localhost:8000"
     fief_client_id: str
     fief_client_secret: str
     fief_encryption_key: Optional[str] = None
